@@ -100,22 +100,15 @@ type key =                            (* the type for property keys (names). *)
 | Emoji_modifier_base
 | Emoji_component
 | Equivalent_unified_ideograph
-| Expands_on_nfc
-| Expands_on_nfd
-| Expands_on_nfkc
-| Expands_on_nfkd
 | Extender
 | Extended_pictographic
-| Fc_nfkc_closure
 | Full_composition_exclusion
 | General_category
 | Grapheme_base
 | Grapheme_cluster_break
 | Grapheme_extend
-| Grapheme_link
 | Hangul_syllable_type
 | Hex_digit
-| Hyphen
 | Id_continue
 | Id_compat_math_continue
 | Id_compat_math_start
@@ -128,7 +121,6 @@ type key =                            (* the type for property keys (names). *)
 | Indic_syllabic_category
 | Indic_matra_category
 | Indic_positional_category
-| Iso_comment
 | Jamo_short_name
 | Join_control
 | Joining_group
@@ -216,7 +208,6 @@ type key =                            (* the type for property keys (names). *)
 | KGB1
 | KGB3
 | KGB5
-| KGB7
 | KGB8
 | KGSR
 | KGradeLevel
@@ -247,7 +238,6 @@ type key =                            (* the type for property keys (names). *)
 | KJapanese
 | KJHJ
 | KJIS0213
-| KJa
 | KJapaneseKun
 | KJapaneseOn
 | KJinmeiyoKanji
@@ -271,6 +261,8 @@ type key =                            (* the type for property keys (names). *)
 | KMojiJoho
 | KMorohashi
 | KNelson
+| KNSHU_DubenSrc
+| KNSHU_Reading
 | KOtherNumeric
 | KPhonetic
 | KPrimaryNumeric
@@ -281,9 +273,7 @@ type key =                            (* the type for property keys (names). *)
 | KRSKangXi
 | KRSKorean
 | KRSMerged
-| KRSTUnicode
 | KRSUnicode
-| KReading
 | KSBGY
 | KSemanticVariant
 | KSimplifiedVariant
@@ -291,13 +281,14 @@ type key =                            (* the type for property keys (names). *)
 | KSMSZD2003Readings
 | KSpecializedSemanticVariant
 | KSpoofingVariant
-| KSrc_NushuDuben
 | KStrange
 | KTGH
 | KTGHZ2013
 | KTGT_MergedSrc
+| KTGT_RSUnicode
 | KTaiwanTelegraph
 | KTang
+| KTayNumeric
 | KTotalStrokes
 | KTraditionalVariant
 | KUnihanCore2020
@@ -309,6 +300,19 @@ type key =                            (* the type for property keys (names). *)
 | KZhuang
 | KZhuangNumeric
 | KZVariant
+(* Unikemet *)
+| KEH_Cat
+| KEH_Core
+| KEH_Desc
+| KEH_Func
+| KEH_FVal
+| KEH_UniK
+| KEH_JSesh
+| KEH_HG
+| KEH_IFAO
+| KEH_NoMirror
+| KEH_NoRotate
+| KEH_AltSeq
 | Other of (string * string)                           (* expanded XML name. *)
 
 type script = [
@@ -324,6 +328,7 @@ type script = [
 | `Bass
 | `Batk
 | `Beng
+| `Berf
 | `Bhks
 | `Bopo
 | `Brah
@@ -444,6 +449,7 @@ type script = [
 | `Shaw
 | `Shrd
 | `Sidd
+| `Sidt
 | `Sind
 | `Sinh
 | `Sogd
@@ -461,6 +467,7 @@ type script = [
 | `Taml
 | `Tang
 | `Tavt
+| `Tayo
 | `Telu
 | `Tfng
 | `Tglg
@@ -470,6 +477,7 @@ type script = [
 | `Tirh
 | `Tnsa
 | `Todr
+| `Tols
 | `Toto
 | `Tutg
 | `Ugar
@@ -515,6 +523,7 @@ type block_prop = [
 | `Bassa_Vah
 | `Batak
 | `Bengali
+| `Beria_Erfe
 | `Bhaiksuki
 | `Block_Elements
 | `Bopomofo
@@ -539,6 +548,7 @@ type block_prop = [
 | `CJK_Ext_G
 | `CJK_Ext_H
 | `CJK_Ext_I
+| `CJK_Ext_J
 | `CJK_Radicals_Sup
 | `CJK_Strokes
 | `CJK_Symbols
@@ -696,6 +706,7 @@ type block_prop = [
 | `Misc_Math_Symbols_B
 | `Misc_Pictographs
 | `Misc_Symbols
+| `Misc_Symbols_Sup
 | `Misc_Technical
 | `Modi
 | `Modifier_Letters
@@ -755,9 +766,11 @@ type block_prop = [
 | `Samaritan
 | `Saurashtra
 | `Sharada
+| `Sharada_Sup
 | `Shavian
 | `Shorthand_Format_Controls
 | `Siddham
+| `Sidetic
 | `Sinhala
 | `Sinhala_Archaic_Numbers
 | `Small_Forms
@@ -792,12 +805,14 @@ type block_prop = [
 | `Tai_Tham
 | `Tai_Viet
 | `Tai_Xuan_Jing
+| `Tai_Yo
 | `Takri
 | `Tamil
 | `Tamil_Sup
 | `Tangsa
 | `Tangut
 | `Tangut_Components
+| `Tangut_Components_Sup
 | `Tangut_Sup
 | `Telugu
 | `Thaana
@@ -806,6 +821,7 @@ type block_prop = [
 | `Tifinagh
 | `Tirhuta
 | `Todhri
+| `Tolong_Siki
 | `Toto
 | `Transport_And_Map
 | `Tulu_Tigalari
@@ -1002,6 +1018,7 @@ type value =                                (* the type for property values. *)
     | `Bottom
     | `Bottom_And_Left
     | `Bottom_And_Right
+    | `Invisible
     | `Left
     | `Left_And_Right
     | `NA
@@ -1114,6 +1131,7 @@ type value =                                (* the type for property values. *)
     | `Teh_Marbuta
     | `Teh_Marbuta_Goal
     | `Teth
+    | `Thin_Noon
     | `Thin_Yeh
     | `Vertical_Tail
     | `Waw
@@ -1124,7 +1142,20 @@ type value =                                (* the type for property values. *)
     | `Yudh_He
     | `Zain
     | `Zhain
-  ]
+    | `BAA
+    | `FA
+    | `HAA
+    | `HA_GOAL
+    | `HA
+    | `CAF
+    | `KNOTTED_HA
+    | `RA
+    | `SWASH_CAF
+    | `HAMZAH_ON_HA_GOAL
+    | `TAA_MARBUTAH
+    | `YA_BARREE
+    | `YA
+    | `ALEF_MAQSURAH ]
 | Joining_type_v of [ `U | `C | `T | `D | `L | `R ]
 | Line_break_v of [
     | `AI
@@ -1148,6 +1179,7 @@ type value =                                (* the type for property values. *)
     | `GL
     | `H2
     | `H3
+    | `HH
     | `HL
     | `HY
     | `ID
@@ -1364,6 +1396,7 @@ let i_block v = Block_v begin match v with
 | "Bassa_Vah" -> `Bassa_Vah
 | "Batak" -> `Batak
 | "Bengali" -> `Bengali
+| "Beria_Erfe" -> `Beria_Erfe
 | "Bhaiksuki" -> `Bhaiksuki
 | "Block_Elements" -> `Block_Elements
 | "Bopomofo" -> `Bopomofo
@@ -1388,6 +1421,7 @@ let i_block v = Block_v begin match v with
 | "CJK_Ext_G" -> `CJK_Ext_G
 | "CJK_Ext_H" -> `CJK_Ext_H
 | "CJK_Ext_I" -> `CJK_Ext_I
+| "CJK_Ext_J" -> `CJK_Ext_J
 | "CJK_Radicals_Sup" -> `CJK_Radicals_Sup
 | "CJK_Strokes" -> `CJK_Strokes
 | "CJK_Symbols" -> `CJK_Symbols
@@ -1545,6 +1579,7 @@ let i_block v = Block_v begin match v with
 | "Misc_Math_Symbols_B" -> `Misc_Math_Symbols_B
 | "Misc_Pictographs" -> `Misc_Pictographs
 | "Misc_Symbols" -> `Misc_Symbols
+| "Misc_Symbols_Sup" -> `Misc_Symbols_Sup
 | "Misc_Technical" -> `Misc_Technical
 | "Modi" -> `Modi
 | "Modifier_Letters" -> `Modifier_Letters
@@ -1604,9 +1639,11 @@ let i_block v = Block_v begin match v with
 | "Samaritan" -> `Samaritan
 | "Saurashtra" -> `Saurashtra
 | "Sharada" -> `Sharada
+| "Sharada_Sup" -> `Sharada_Sup
 | "Shavian" -> `Shavian
 | "Shorthand_Format_Controls" -> `Shorthand_Format_Controls
 | "Siddham" -> `Siddham
+| "Sidetic" -> `Sidetic
 | "Sinhala" -> `Sinhala
 | "Sinhala_Archaic_Numbers" -> `Sinhala_Archaic_Numbers
 | "Small_Forms" -> `Small_Forms
@@ -1641,12 +1678,14 @@ let i_block v = Block_v begin match v with
 | "Tai_Tham" -> `Tai_Tham
 | "Tai_Viet" -> `Tai_Viet
 | "Tai_Xuan_Jing" -> `Tai_Xuan_Jing
+| "Tai_Yo" -> `Tai_Yo
 | "Takri" -> `Takri
 | "Tamil" -> `Tamil
 | "Tamil_Sup" -> `Tamil_Sup
 | "Tangsa" -> `Tangsa
 | "Tangut" -> `Tangut
 | "Tangut_Components" -> `Tangut_Components
+| "Tangut_Components_Sup" -> `Tangut_Components_Sup
 | "Tangut_Sup" -> `Tangut_Sup
 | "Telugu" -> `Telugu
 | "Thaana" -> `Thaana
@@ -1655,6 +1694,7 @@ let i_block v = Block_v begin match v with
 | "Tifinagh" -> `Tifinagh
 | "Tirhuta" -> `Tirhuta
 | "Todhri" -> `Todhri
+| "Tolong_Siki" -> `Tolong_Siki
 | "Toto" -> `Toto
 | "Transport_And_Map" -> `Transport_And_Map
 | "Tulu_Tigalari" -> `Tulu_Tigalari
@@ -1873,6 +1913,7 @@ begin match v with
 | "Bottom" -> `Bottom
 | "Bottom_And_Left" -> `Bottom_And_Right
 | "Bottom_And_Right" -> `Bottom_And_Right
+| "Invisible" -> `Invisible
 | "Left" -> `Left
 | "Left_And_Right" -> `Left_And_Right
 | "NA" -> `NA
@@ -1987,6 +2028,7 @@ let i_joining_group v = Joining_group_v begin match v with
 | "Teh_Marbuta" -> `Teh_Marbuta
 | "Teh_Marbuta_Goal" -> `Teh_Marbuta_Goal
 | "Teth" -> `Teth
+| "Thin_Noon" -> `Thin_Noon
 | "Thin_Yeh" -> `Thin_Yeh
 | "Vertical_Tail" -> `Vertical_Tail
 | "Waw" -> `Waw
@@ -1997,6 +2039,20 @@ let i_joining_group v = Joining_group_v begin match v with
 | "Yudh_He" -> `Yudh_He
 | "Zain" -> `Zain
 | "Zhain" -> `Zhain
+| "BAA" -> `BAA
+| "FA" -> `FA
+| "HAA" -> `HAA
+| "HA_GOAL" -> `HA_GOAL
+| "HA" -> `HA
+| "CAF" -> `CAF
+| "KNOTTED_HA" -> `KNOTTED_HA
+| "RA" -> `RA
+| "SWASH_CAF" -> `SWASH_CAF
+| "HAMZAH_ON_HA_GOAL" -> `HAMZAH_ON_HA_GOAL
+| "TAA_MARBUTAH" -> `TAA_MARBUTAH
+| "YA_BARREE" -> `YA_BARREE
+| "YA" -> `YA
+| "ALEF_MAQSURAH " -> `ALEF_MAQSURAH
 | v -> err (err_att_val v)
 end
 
@@ -2032,6 +2088,7 @@ let i_line_break v = Line_break_v begin match v with
 | "GL" -> `GL
 | "H2" -> `H2
 | "H3" -> `H3
+| "HH" -> `HH
 | "HL" -> `HL
 | "HY" -> `HY
 | "ID" -> `ID
@@ -2104,6 +2161,7 @@ let i_script v = Script_v begin match v with
 | "Bass" -> `Bass
 | "Batk" -> `Batk
 | "Beng" -> `Beng
+| "Berf" -> `Berf
 | "Bhks" -> `Bhks
 | "Bopo" -> `Bopo
 | "Brah" -> `Brah
@@ -2224,6 +2282,7 @@ let i_script v = Script_v begin match v with
 | "Shaw" -> `Shaw
 | "Shrd" -> `Shrd
 | "Sidd" -> `Sidd
+| "Sidt" -> `Sidt
 | "Sind" -> `Sind
 | "Sinh" -> `Sinh
 | "Sogd" -> `Sogd
@@ -2241,6 +2300,7 @@ let i_script v = Script_v begin match v with
 | "Taml" -> `Taml
 | "Tang" -> `Tang
 | "Tavt" -> `Tavt
+| "Tayo" -> `Tayo
 | "Telu" -> `Telu
 | "Tfng" -> `Tfng
 | "Tglg" -> `Tglg
@@ -2250,6 +2310,7 @@ let i_script v = Script_v begin match v with
 | "Tirh" -> `Tirh
 | "Tnsa" -> `Tnsa
 | "Todr" -> `Todr
+| "Tols" -> `Tols
 | "Toto" -> `Toto
 | "Tutg" -> `Tutg
 | "Ugar" -> `Ugar
@@ -2344,7 +2405,7 @@ let find props (k, o) = try Some (o (Pmap.find k props)) with Not_found -> None
 let unknown_prop name = (Other name), o_string
 
 
-(* non hunihan properties *)
+(* non hunihan and unikemet properties *)
 
 let uax_42_element = UAX_42_element, o_uax_42_element    (* artefact of Uucd *)
 
@@ -2385,21 +2446,14 @@ let emoji_modifier_base = Emoji_modifier_base, o_bool
 let emoji_component = Emoji_component, o_bool
 let equivalent_unified_ideograph = Equivalent_unified_ideograph, o_cp_opt
 let extended_pictographic = Extended_pictographic, o_bool
-let expands_on_nfc = Expands_on_nfc, o_bool
-let expands_on_nfd = Expands_on_nfd, o_bool
-let expands_on_nfkc = Expands_on_nfkc, o_bool
-let expands_on_nfkd = Expands_on_nfkd, o_bool
 let extender = Extender, o_bool
-let fc_nfkc_closure = Fc_nfkc_closure, o_cps_map
 let full_composition_exclusion = Full_composition_exclusion, o_bool
 let general_category = General_category, o_general_category
 let grapheme_base = Grapheme_base, o_bool
 let grapheme_cluster_break = Grapheme_cluster_break, o_grapheme_cluster_break
 let grapheme_extend = Grapheme_extend, o_bool
-let grapheme_link = Grapheme_link, o_bool
 let hangul_syllable_type = Hangul_syllable_type, o_hangul_syllable_type
 let hex_digit = Hex_digit, o_bool
-let hyphen = Hyphen, o_bool
 let id_continue = Id_continue, o_bool
 let id_compat_math_continue = Id_compat_math_continue, o_bool
 let id_compat_math_start = Id_compat_math_start, o_bool
@@ -2413,7 +2467,6 @@ let indic_syllabic_category = Indic_syllabic_category, o_indic_syllabic_category
 let indic_matra_category = Indic_matra_category, o_indic_matra_category
 let indic_positional_category =
   Indic_positional_category, o_indic_positional_category
-let iso_comment = Iso_comment, o_string
 let jamo_short_name = Jamo_short_name, o_string
 let join_control = Join_control, o_bool
 let joining_group = Joining_group, o_joining_group
@@ -2504,7 +2557,6 @@ let kGB0 = KGB0, o_string
 let kGB1 = KGB1, o_string
 let kGB3 = KGB3, o_string
 let kGB5 = KGB5, o_string
-let kGB7 = KGB7, o_string
 let kGB8 = KGB8, o_string
 let kGSR = KGSR, o_string
 let kGradeLevel = KGradeLevel, o_string
@@ -2534,7 +2586,6 @@ let kIRG_UKSource = KIRG_UKSource, o_string
 let kIRG_VSource = KIRG_VSource, o_string
 let kJHJ = KJHJ, o_string
 let kJIS0213 = KJIS0213, o_string
-let kJa = KJa, o_string
 let kJapanese = KJapanese, o_string
 let kJapaneseKun = KJapaneseKun, o_string
 let kJapaneseOn = KJapaneseOn, o_string
@@ -2559,6 +2610,8 @@ let kMeyerWempe = KMeyerWempe, o_string
 let kMojiJoho = KMojiJoho, o_string
 let kMorohashi = KMorohashi, o_string
 let kNelson = KNelson, o_string
+let kNSHU_DubenSrc = KNSHU_DubenSrc, o_string
+let kNSHU_Reading = KNSHU_Reading, o_string
 let kOtherNumeric = KOtherNumeric, o_string
 let kPhonetic = KPhonetic, o_string
 let kPrimaryNumeric = KPrimaryNumeric, o_string
@@ -2569,9 +2622,7 @@ let kRSKanWa = KRSKanWa, o_string
 let kRSKangXi = KRSKangXi, o_string
 let kRSKorean = KRSKorean, o_string
 let kRSMerged = KRSMerged, o_string
-let kRSTUnicode = KRSTUnicode, o_string
 let kRSUnicode = KRSUnicode, o_string
-let kReading = KReading, o_string
 let kSBGY = KSBGY, o_string
 let kSemanticVariant = KSemanticVariant, o_string
 let kSimplifiedVariant = KSimplifiedVariant, o_string
@@ -2579,13 +2630,14 @@ let kSMSZD2003Index = KSMSZD2003Index, o_string
 let kSMSZD2003Readings = KSMSZD2003Readings, o_string
 let kSpecializedSemanticVariant = KSpecializedSemanticVariant, o_string
 let kSpoofingVariant = KSpoofingVariant, o_string
-let kSrc_NushuDuben = KSrc_NushuDuben, o_string
 let kStrange = KStrange, o_string
 let kTGH = KTGH, o_string
 let kTGHZ2013 = KTGHZ2013, o_string
 let kTGT_MergedSrc = KTGT_MergedSrc, o_string
+let kTGT_RSUnicode = KTGT_RSUnicode, o_string
 let kTaiwanTelegraph = KTaiwanTelegraph, o_string
 let kTang = KTang, o_string
+let kTayNumeric = KTayNumeric, o_string
 let kTotalStrokes = KTotalStrokes, o_string
 let kTraditionalVariant = KTraditionalVariant, o_string
 let kUnihanCore2020 = KUnihanCore2020, o_string
@@ -2598,16 +2650,30 @@ let kZhuang = KZhuang, o_string
 let kZhuangNumeric = KZhuangNumeric, o_string
 let kZVariant = KZVariant, o_string
 
+(* Unikemet properties *)
+
+let kEH_Cat = KEH_Cat, o_string
+let kEH_Core = KEH_Core, o_string
+let kEH_Desc = KEH_Desc, o_string
+let kEH_Func = KEH_Func, o_string
+let kEH_FVal = KEH_FVal, o_string
+let kEH_UniK = KEH_UniK, o_string
+let kEH_JSesh = KEH_JSesh, o_string
+let kEH_HG = KEH_HG, o_string
+let kEH_IFAO = KEH_IFAO, o_string
+let kEH_NoMirror = KEH_NoMirror, o_bool
+let kEH_NoRotate = KEH_NoRotate, o_bool
+let kEH_AltSeq = KEH_AltSeq, o_string
+
+
 (* Unicode Character Databases *)
 
 type block = (cp * cp) * string
 type named_sequence = string * cp list
-type normalization_correction = cp * cp list * cp list * (int * int * int)
 type standardized_variant =
   cp list * string * [ `Isolate | `Initial | `Medial | `Final ] list
 
 type cjk_radical = string * cp * cp
-type emoji_source = cp list * int option * int option * int option
 type do_not_emit = { instead_of : cp list; use : cp list; because : string; }
 
 type t =
@@ -2616,10 +2682,8 @@ type t =
     blocks : block list;
     named_sequences : named_sequence list;
     provisional_named_sequences : named_sequence list;
-    normalization_corrections : normalization_correction list;
     standardized_variants : standardized_variant list;
     cjk_radicals : cjk_radical list;
-    emoji_sources : emoji_source list;
     do_not_emit : do_not_emit list; }
 
 let cp_props db cp =
@@ -2640,16 +2704,12 @@ let n_cjk_radical = (ns_ucd, "cjk-radical")
 let n_cjk_radicals = (ns_ucd, "cjk-radicals")
 let n_do_not_emit = (ns_ucd, "do-not-emit")
 let n_description = (ns_ucd, "description")
-let n_emoji_source = (ns_ucd, "emoji-source")
-let n_emoji_sources = (ns_ucd, "emoji-sources")
 let n_group = (ns_ucd, "group")
 let n_instead = (ns_ucd, "instead")
 let n_name_alias = (ns_ucd, "name-alias")
 let n_named_sequence = (ns_ucd, "named-sequence")
 let n_named_sequences = (ns_ucd, "named-sequences")
 let n_noncharacter = (ns_ucd, "noncharacter")
-let n_normalization_correction = (ns_ucd, "normalization-correction")
-let n_normalization_corrections = (ns_ucd, "normalization-corrections")
 let n_provisional_named_sequences = (ns_ucd, "provisional-named-sequences")
 let n_repertoire = (ns_ucd, "repertoire")
 let n_reserved = (ns_ucd, "reserved")
@@ -2683,13 +2743,10 @@ let add_prop : value Pmap.t -> Xmlm.attribute -> value Pmap.t =
   map "Dia" (Diacritic, i_bool);
   map "EqUIdeo" (Equivalent_unified_ideograph, i_cp_opt);
   map "Ext" (Extender, i_bool);
-  map "FC_NFKC" (Fc_nfkc_closure, i_cps_map ~empty:false);
   map "GCB" (Grapheme_cluster_break, i_grapheme_cluster_break);
   map "Gr_Base" (Grapheme_base, i_bool);
   map "Gr_Ext" (Grapheme_extend, i_bool);
-  map "Gr_Link" (Grapheme_link, i_bool);
   map "Hex" (Hex_digit, i_bool);
-  map "Hyphen" (Hyphen, i_bool);
   map "ID_Compat_Math_Continue" (Id_compat_math_continue, i_bool);
   map "ID_Compat_Math_Start" (Id_compat_math_start, i_bool);
   map "IDC" (Id_continue, i_bool);
@@ -2741,10 +2798,6 @@ let add_prop : value Pmap.t -> Xmlm.attribute -> value Pmap.t =
   map "WSpace" (White_space, i_bool);
   map "XIDC" (Xid_continue, i_bool);
   map "XIDS" (Xid_start, i_bool);
-  map "XO_NFC" (Expands_on_nfc, i_bool);
-  map "XO_NFD" (Expands_on_nfd, i_bool);
-  map "XO_NFKC" (Expands_on_nfkc, i_bool);
-  map "XO_NFKD" (Expands_on_nfkd, i_bool);
   map "age" (Age, i_age);
   map "bc" (Bidi_class, i_bidi_class);
   map "blk" (Block, i_block);
@@ -2764,7 +2817,6 @@ let add_prop : value Pmap.t -> Xmlm.attribute -> value Pmap.t =
   map "ExtPict" (Extended_pictographic, i_bool);
   map "gc" (General_category, i_general_category);
   map "hst" (Hangul_syllable_type, i_hangul_syllable_type);
-  map "isc" (Iso_comment, i_string);
   map "jg" (Joining_group, i_joining_group);
   map "jt" (Joining_type, i_joining_type);
   map "lb" (Line_break, i_line_break);
@@ -2810,7 +2862,6 @@ let add_prop : value Pmap.t -> Xmlm.attribute -> value Pmap.t =
   map "kGB1" (KGB1, i_string);
   map "kGB3" (KGB3, i_string);
   map "kGB5" (KGB5, i_string);
-  map "kGB7" (KGB7, i_string);
   map "kGB8" (KGB8, i_string);
   map "kGSR" (KGSR, i_string);
   map "kGradeLevel" (KGradeLevel, i_string);
@@ -2841,7 +2892,6 @@ let add_prop : value Pmap.t -> Xmlm.attribute -> value Pmap.t =
   map "kJapanese" (KJapanese, i_string);
   map "kJHJ" (KJHJ, i_string);
   map "kJIS0213" (KJIS0213, i_string);
-  map "kJa" (KJa, i_string);
   map "kJapaneseKun" (KJapaneseKun, i_string);
   map "kJapaneseOn" (KJapaneseOn, i_string);
   map "kJinmeiyoKanji" (KJinmeiyoKanji, i_string);
@@ -2864,6 +2914,8 @@ let add_prop : value Pmap.t -> Xmlm.attribute -> value Pmap.t =
   map "kMeyerWempe" (KMeyerWempe, i_string);
   map "kMorohashi" (KMorohashi, i_string);
   map "kNelson" (KNelson, i_string);
+  map "kNSHU_DubenSrc" (KNSHU_DubenSrc, i_string);
+  map "kNSHU_Reading" (KNSHU_Reading, i_string);
   map "kOtherNumeric" (KOtherNumeric, i_string);
   map "kPhonetic" (KPhonetic, i_string);
   map "kPrimaryNumeric" (KPrimaryNumeric, i_string);
@@ -2874,9 +2926,7 @@ let add_prop : value Pmap.t -> Xmlm.attribute -> value Pmap.t =
   map "kRSKangXi" (KRSKangXi, i_string);
   map "kRSKorean" (KRSKorean, i_string);
   map "kRSMerged" (KRSMerged, i_string);
-  map "kRSTUnicode" (KRSTUnicode, i_string);
   map "kRSUnicode" (KRSUnicode, i_string);
-  map "kReading" (KReading, i_string);
   map "kSBGY" (KSBGY, i_string);
   map "kSemanticVariant" (KSemanticVariant, i_string);
   map "kSimplifiedVariant" (KSimplifiedVariant, i_string);
@@ -2884,12 +2934,13 @@ let add_prop : value Pmap.t -> Xmlm.attribute -> value Pmap.t =
   map "kSMSZD2003Readings" (KSMSZD2003Readings, i_string);
   map "kSpecializedSemanticVariant" (KSpecializedSemanticVariant, i_string);
   map "kSpoofingVariant" (KSpoofingVariant, i_string);
-  map "kSrc_NushuDuben" (KSrc_NushuDuben, i_string);
   map "kTGH" (KTGH, i_string);
   map "kTGHZ2013" (KTGHZ2013, i_string);
   map "kTGT_MergedSrc" (KTGT_MergedSrc, i_string);
+  map "kTGT_RSUnicode" (KTGT_RSUnicode, i_string);
   map "kTaiwanTelegraph" (KTaiwanTelegraph, i_string);
   map "kTang" (KTang, i_string);
+  map "kTayNumeric" (KTayNumeric, i_string);
   map "kTotalStrokes" (KTotalStrokes, i_string);
   map "kTraditionalVariant" (KTraditionalVariant, i_string);
   map "kVietnamese" (KVietnamese, i_string);
@@ -2900,6 +2951,18 @@ let add_prop : value Pmap.t -> Xmlm.attribute -> value Pmap.t =
   map "kZhuang" (KZhuang, i_string);
   map "kZhuangNumeric" (KZhuangNumeric, i_string);
   map "kZVariant" (KZVariant, i_string);
+  map "kEH_Cat" (KEH_Cat, i_string);
+  map "kEH_Core" (KEH_Core, i_string);
+  map "kEH_Desc" (KEH_Desc, i_string);
+  map "kEH_Func" (KEH_Func, i_string);
+  map "kEH_FVal" (KEH_FVal, i_string);
+  map "kEH_UniK" (KEH_UniK, i_string);
+  map "kEH_JSesh" (KEH_JSesh, i_string);
+  map "kEH_HG" (KEH_HG, i_string);
+  map "kEH_IFAO" (KEH_IFAO, i_string);
+  map "kEH_NoMirror" (KEH_NoMirror, i_bool);
+  map "kEH_NoRotate" (KEH_NoRotate, i_bool);
+  map "kEH_AltSeq" (KEH_AltSeq, i_string);
   fun m (n, v) ->
     try match n with
     | ("", p) ->
@@ -3016,22 +3079,6 @@ let p_named_sequences d =
   let ns_atts atts = attv "name" atts, cps_of_string (attv "cps" atts) in
   p_seq n_named_sequence ns_atts d
 
-let p_normalization_corrections d =
-  let version_of_string v =
-    try
-      match List.map int_of_string (split_string v '.') with
-      | [v1; v2; v3;] -> (v1, v2, v3)
-      | _ -> failwith ""
-    with Failure _ -> err (err_att_val v)
-  in
-  let nc_atts atts =
-    cp_of_string (attv "cp" atts),
-    cps_of_string (attv "old" atts),
-    cps_of_string (attv "new" atts),
-    version_of_string (attv "version" atts)
-  in
-  p_seq n_normalization_correction nc_atts d
-
 let p_standardized_variants d =
   let when_of_string v =
     let w s = match s with
@@ -3058,16 +3105,6 @@ let p_cjk_radicals d =
   in
   p_seq n_cjk_radical cjk_r_atts d
 
-let p_emoji_sources d =
-  let es_atts atts =
-    let opt_int v = if v = "" then None else Some (cp_of_string v) in
-    cps_of_string (attv "unicode" atts),
-    opt_int (attv "docomo" atts),
-    opt_int (attv "kddi" atts),
-    opt_int (attv "softbank" atts)
-  in
-  p_seq n_emoji_source es_atts d
-
 let p_do_not_emit d =
   let instead_atts atts =
     let instead_of = cps_of_string (attv "of" atts) in
@@ -3083,10 +3120,8 @@ let p_ucd d =
   let blocks = ref None in
   let named_sequences = ref None in
   let provisional_named_sequences = ref None in
-  let normalization_corrections = ref None in
   let standardized_variants = ref None in
   let cjk_radicals = ref None in
-  let emoji_sources = ref None in
   let do_not_emit = ref None in
   let set n r p d = if !r <> None then err (err_dup n) else r := Some (p d) in
   while (Xmlm.peek d <> `El_end) do match Xmlm.input d with
@@ -3100,14 +3135,10 @@ let p_ucd d =
       set n named_sequences p_named_sequences d
   | `El_start (n, _) when n = n_provisional_named_sequences ->
       set n provisional_named_sequences p_named_sequences d
-  | `El_start (n, _) when n = n_normalization_corrections ->
-      set n normalization_corrections p_normalization_corrections d
   | `El_start (n, _) when n = n_standardized_variants ->
       set n standardized_variants p_standardized_variants d
   | `El_start (n, _) when n = n_cjk_radicals ->
       set n cjk_radicals p_cjk_radicals d
-  | `El_start (n, _) when n = n_emoji_sources ->
-      set n emoji_sources p_emoji_sources d
   | `El_start (n, _) when n = n_do_not_emit ->
       set n do_not_emit p_do_not_emit d
   | `El_start (n, _) -> skip_el d                        (* foreign markup *)
@@ -3122,10 +3153,8 @@ let p_ucd d =
     blocks = some !blocks [];
     named_sequences = some !named_sequences [];
     provisional_named_sequences = some !provisional_named_sequences [];
-    normalization_corrections = some !normalization_corrections [];
     standardized_variants = some !standardized_variants [];
     cjk_radicals = some !cjk_radicals [];
-    emoji_sources = some !emoji_sources [];
     do_not_emit = some !do_not_emit []; }
 
 type src = [ `Channel of in_channel | `String of string ]
