@@ -140,6 +140,7 @@ val block : [
 | `Bassa_Vah
 | `Batak
 | `Bengali
+| `Beria_Erfe
 | `Bhaiksuki
 | `Block_Elements
 | `Bopomofo
@@ -164,6 +165,7 @@ val block : [
 | `CJK_Ext_G
 | `CJK_Ext_H
 | `CJK_Ext_I
+| `CJK_Ext_J
 | `CJK_Radicals_Sup
 | `CJK_Strokes
 | `CJK_Symbols
@@ -321,6 +323,7 @@ val block : [
 | `Misc_Math_Symbols_B
 | `Misc_Pictographs
 | `Misc_Symbols
+| `Misc_Symbols_Sup
 | `Misc_Technical
 | `Modi
 | `Modifier_Letters
@@ -380,9 +383,11 @@ val block : [
 | `Samaritan
 | `Saurashtra
 | `Sharada
+| `Sharada_Sup
 | `Shavian
 | `Shorthand_Format_Controls
 | `Siddham
+| `Sidetic
 | `Sinhala
 | `Sinhala_Archaic_Numbers
 | `Small_Forms
@@ -417,12 +422,14 @@ val block : [
 | `Tai_Tham
 | `Tai_Viet
 | `Tai_Xuan_Jing
+| `Tai_Yo
 | `Takri
 | `Tamil
 | `Tamil_Sup
 | `Tangsa
 | `Tangut
 | `Tangut_Components
+| `Tangut_Components_Sup
 | `Tangut_Sup
 | `Telugu
 | `Thaana
@@ -431,6 +438,7 @@ val block : [
 | `Tifinagh
 | `Tirhuta
 | `Todhri
+| `Tolong_Siki
 | `Toto
 | `Transport_And_Map
 | `Tulu_Tigalari
@@ -498,13 +506,8 @@ val emoji_modifier : bool prop
 val emoji_modifier_base : bool prop
 val emoji_component : bool prop
 val equivalent_unified_ideograph : cp option prop
-val expands_on_nfc : bool prop
-val expands_on_nfd : bool prop
-val expands_on_nfkc : bool prop
-val expands_on_nfkd : bool prop
 val extended_pictographic : bool prop
 val extender : bool prop
-val fc_nfkc_closure : [ `Self | `Cps of cp list ] prop
 val full_composition_exclusion : bool prop
 val general_category : [
 | `Lu
@@ -562,10 +565,8 @@ val grapheme_cluster_break : [
 ] prop
 
 val grapheme_extend : bool prop
-val grapheme_link : bool prop
 val hangul_syllable_type : [ `L | `LV | `LVT | `T | `V | `NA ] prop
 val hex_digit : bool prop
-val hyphen : bool prop
 val id_continue : bool prop
 val id_compat_math_continue : bool prop
 val id_compat_math_start : bool prop
@@ -644,6 +645,7 @@ val indic_positional_category : [
 | `Bottom
 | `Bottom_And_Left
 | `Bottom_And_Right
+| `Invisible
 | `Left
 | `Left_And_Right
 | `NA
@@ -659,7 +661,6 @@ val indic_positional_category : [
 | `Visual_Order_Left
 ] prop
 
-val iso_comment : string prop
 val jamo_short_name : string prop
 val join_control : bool prop
 val joining_group : [
@@ -760,6 +761,7 @@ val joining_group : [
 | `Teh_Marbuta
 | `Teh_Marbuta_Goal
 | `Teth
+| `Thin_Noon
 | `Thin_Yeh
 | `Vertical_Tail
 | `Waw
@@ -770,6 +772,20 @@ val joining_group : [
 | `Yudh_He
 | `Zain
 | `Zhain
+| `BAA
+| `FA
+| `HAA
+| `HA_GOAL
+| `HA
+| `CAF
+| `KNOTTED_HA
+| `RA
+| `SWASH_CAF
+| `HAMZAH_ON_HA_GOAL
+| `TAA_MARBUTAH
+| `YA_BARREE
+| `YA
+| `ALEF_MAQSURAH
 ] prop
 
 val joining_type : [ `U | `C | `T | `D | `L | `R ] prop
@@ -793,6 +809,7 @@ val line_break : [
 | `GL
 | `H2
 | `H3
+| `HH
 | `HL
 | `HY
 | `ID
@@ -880,6 +897,7 @@ type script = [
 | `Bass
 | `Batk
 | `Beng
+| `Berf
 | `Bhks
 | `Bopo
 | `Brah
@@ -1000,6 +1018,7 @@ type script = [
 | `Shaw
 | `Shrd
 | `Sidd
+| `Sidt
 | `Sind
 | `Sinh
 | `Sogd
@@ -1017,6 +1036,7 @@ type script = [
 | `Taml
 | `Tang
 | `Tavt
+| `Tayo
 | `Telu
 | `Tfng
 | `Tglg
@@ -1026,6 +1046,7 @@ type script = [
 | `Tirh
 | `Tnsa
 | `Todr
+| `Tols
 | `Toto
 | `Tutg
 | `Ugar
@@ -1147,7 +1168,6 @@ val kGB0 : string prop
 val kGB1 : string prop
 val kGB3 : string prop
 val kGB5 : string prop
-val kGB7 : string prop
 val kGB8 : string prop
 val kGSR : string prop
 val kGradeLevel : string prop
@@ -1175,7 +1195,6 @@ val kIRG_TSource : string prop
 val kIRG_USource : string prop
 val kIRG_UKSource : string prop
 val kIRG_VSource : string prop
-val kJa : string prop
 val kJapanese : string prop
 val kJapaneseKun : string prop
 val kJapaneseOn : string prop
@@ -1202,6 +1221,8 @@ val kMeyerWempe : string prop
 val kMojiJoho : string prop
 val kMorohashi : string prop
 val kNelson : string prop
+val kNSHU_DubenSrc : string prop
+val kNSHU_Reading : string prop
 val kOtherNumeric : string prop
 val kPhonetic : string prop
 val kPrimaryNumeric : string prop
@@ -1212,9 +1233,7 @@ val kRSKanWa : string prop
 val kRSKangXi : string prop
 val kRSKorean : string prop
 val kRSMerged : string prop
-val kRSTUnicode : string prop
 val kRSUnicode : string prop
-val kReading : string prop
 val kSBGY : string prop
 val kSemanticVariant : string prop
 val kSimplifiedVariant : string prop
@@ -1222,14 +1241,15 @@ val kSMSZD2003Index : string prop
 val kSMSZD2003Readings : string prop
 val kSpecializedSemanticVariant : string prop
 val kSpoofingVariant : string prop
-val kSrc_NushuDuben : string prop
 val kStrange : string prop
 val kUnihanCore2020 : string prop
 val kTGH : string prop
 val kTGHZ2013 : string prop
 val kTGT_MergedSrc : string prop
+val kTGT_RSUnicode : string prop
 val kTaiwanTelegraph : string prop
 val kTang : string prop
+val kTayNumeric : string prop
 val kTotalStrokes : string prop
 val kTraditionalVariant : string prop
 val kVietnamese : string prop
@@ -1241,6 +1261,21 @@ val kXerox : string prop
 val kZhuangNumeric : string prop
 val kZVariant : string prop
 
+(** {1:unikemet Unikemet properties} *)
+
+val kEH_Cat : string prop
+val kEH_Core : string prop
+val kEH_Desc : string prop
+val kEH_Func : string prop
+val kEH_FVal : string prop
+val kEH_UniK : string prop
+val kEH_JSesh : string prop
+val kEH_HG : string prop
+val kEH_IFAO : string prop
+val kEH_NoMirror : bool prop
+val kEH_NoRotate : bool prop
+val kEH_AltSeq : string prop
+
 (** {1:db Unicode character databases} *)
 
 type block = (cp * cp) * string
@@ -1249,11 +1284,6 @@ type block = (cp * cp) * string
 type named_sequence = string * cp list
 (** The type for named sequences. Sequence name, code point sequence. *)
 
-type normalization_correction =
-    cp * cp list * cp list * (int * int * int)
-(** The type for normalization corrections.
-    Code point, old normalization, new normalization, version *)
-
 type standardized_variant =
     cp list * string * [ `Isolate | `Initial | `Medial | `Final ] list
 (** The type for standarized variants. Code point sequence,
@@ -1263,9 +1293,6 @@ type cjk_radical = string * cp * cp
 (** The type for CJK radicals. Radical number, CJK radical character,
     CJK unified ideograph. *)
 
-type emoji_source = cp list * int option * int option * int option
-(** The type for emoji sources. Unicode, docomo, kddi, softbank. *)
-
 type do_not_emit = { instead_of : cp list; use : cp list; because : string; }
 (** The type for do not emit character sequences. *)
 
@@ -1275,10 +1302,8 @@ type t =
     blocks : block list;
     named_sequences : named_sequence list;
     provisional_named_sequences : named_sequence list;
-    normalization_corrections : normalization_correction list;
     standardized_variants : standardized_variant list;
     cjk_radicals : cjk_radical list;
-    emoji_sources : emoji_source list;
     do_not_emit : do_not_emit list
 }
 (** The type for Unicode character databases.
